Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Data ¶
type Data struct {
Figure models.Figure
Field [][]int
FigureType int
StartTime time.Time
PlayerScore int
}
func (*Data) CheckFilledLines ¶
func (d *Data) CheckFilledLines()
Checks for filled lines, removes them if found and increases the score
func (*Data) Create ¶
func (d *Data) Create()
This function is responsible for creating a new shape with random coordinates on the x-axis and random rotation
func (*Data) EndStats ¶
func (d *Data) EndStats()
Printing of the player's score along with the exit from the game
func (*Data) ReadingKeyboard ¶
func (d *Data) ReadingKeyboard()
This function is responsible for controlling the falling figure with the keyboard
Click to show internal directories.
Click to hide internal directories.